@@ -44,8 +44,6 @@ main (int argc, char *argv [])
 	glibtop_sysdeps sysdeps;
 	unsigned c, method, count, port, i, *ptr;
 	char buffer [BUFSIZ];
-	struct rlimit rlim;
-	struct rusage ru;
 	pid_t pid, ppid;
 
 	count = PROFILE_COUNT;
@@ -223,16 +221,17 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_state (&data.proc_state, pid);
 
-	printf ("Proc_State   PID  %5u (0x%08lx): '%s', %c, %u, %u\n", pid,
-		(unsigned long) data.proc_state.flags,
+	printf ("Proc_State   PID  %5d (0x%08lx): '%s', %c, %lu, %lu\n",
+		(int) pid, (unsigned long) data.proc_state.flags,
 		data.proc_state.cmd, data.proc_state.state,
-		data.proc_state.uid, data.proc_state.gid);
+		(unsigned long) data.proc_state.uid,
+		(unsigned long) data.proc_state.gid);
 
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_uid (&data.proc_uid, pid);
 
-	printf ("Proc_Uid     PID  %5u (0x%08lx): "
-		"%d %d %d %d %d %d %d %d %d %d %d %d\n", pid,
+	printf ("Proc_Uid     PID  %5d (0x%08lx): "
+		"%d %d %d %d %d %d %d %d %d %d %d %d\n", (int) pid,
 		(unsigned long) data.proc_uid.flags,
 		data.proc_uid.uid, data.proc_uid.euid,
 		data.proc_uid.gid, data.proc_uid.egid,
@@ -244,15 +243,8 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_mem (&data.proc_mem, pid);
 
-	getrlimit (RLIMIT_RSS, &rlim);
-
-	fprintf (stderr, "GETRLIM: %lu - %lu - %lu\n",
-		 (unsigned long) rlim.rlim_cur,
-		 (unsigned long) rlim.rlim_max,
-		 (unsigned long) ((1 << 63) - 1));
-
-	printf ("Proc_Mem     PID  %5u (0x%08lx): "
-		"%lu %lu %lu %lu %lu %lu\n", pid,
+	printf ("Proc_Mem     PID  %5d (0x%08lx): "
+		"%lu %lu %lu %lu %lu %lu\n", (int) pid,
 		(unsigned long) data.proc_mem.flags,
 		(unsigned long) data.proc_mem.size,
 		(unsigned long) data.proc_mem.vsize,
@@ -264,8 +256,8 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_segment (&data.proc_segment, pid);
 
-	printf ("Proc_Segment PID  %5u (0x%08lx): "
-		"%lu %lu %lu %lu %lu %lu %lu %lu\n", pid,
+	printf ("Proc_Segment PID  %5d (0x%08lx): "
+		"%lu %lu %lu %lu %lu %lu %lu %lu\n", (int) pid,
 		(unsigned long) data.proc_segment.flags,
 		(unsigned long) data.proc_segment.text_rss,
 		(unsigned long) data.proc_segment.shlib_rss,
@@ -276,17 +268,11 @@ main (int argc, char *argv [])
 		(unsigned long) data.proc_segment.end_code,
 		(unsigned long) data.proc_segment.start_stack);
 
-	getrusage (RUSAGE_SELF, &ru);
-
-	fprintf (stderr, "GETRUSAGE: (%ld, %ld) - (%ld, %ld)\n",
-		 ru.ru_utime.tv_sec, ru.ru_utime.tv_usec,
-		 ru.ru_stime.tv_sec, ru.ru_stime.tv_usec);
-
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_time (&data.proc_time, pid);
 
-	printf ("Proc_Time    PID  %5u (0x%08lx): "
-		"%lu %lu %lu %lu %lu %lu %lu %lu %lu\n", pid,
+	printf ("Proc_Time    PID  %5d (0x%08lx): "
+		"%lu %lu %lu %lu %lu %lu %lu %lu %lu\n", (int) pid,
 		(unsigned long) data.proc_time.flags,
 		(unsigned long) data.proc_time.start_time,
 		(unsigned long) data.proc_time.rtime,
@@ -301,8 +287,8 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_signal (&data.proc_signal, pid);
 	
-	printf ("Proc_Signal  PID  %5u (0x%08lx): "
-		"%lu %lu %lu %lu\n", pid,
+	printf ("Proc_Signal  PID  %5d (0x%08lx): "
+		"%lu %lu %lu %lu\n", (int) pid,
 		(unsigned long) data.proc_signal.flags,
 		(unsigned long) data.proc_signal.signal,
 		(unsigned long) data.proc_signal.blocked,
@@ -312,8 +298,8 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_kernel (&data.proc_kernel, pid);
 
-	printf ("Proc_Kernel  PID  %5u (0x%08lx): "
-		"%lu %lu %lu %lu %lu %lu %lu %lu (%s)\n", pid,
+	printf ("Proc_Kernel  PID  %5d (0x%08lx): "
+		"%lu %lu %lu %lu %lu %lu %lu %lu (%s)\n", (int) pid,
 		(unsigned long) data.proc_kernel.flags,
 		(unsigned long) data.proc_kernel.k_flags,
 		(unsigned long) data.proc_kernel.min_flt,
@@ -330,16 +316,17 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_state (&data.proc_state, ppid);
 
-	printf ("Proc_State   PPID %5u (0x%08lx): '%s', %c, %u, %u\n", ppid,
-		(unsigned long) data.proc_state.flags,
+	printf ("Proc_State   PPID %5d (0x%08lx): '%s', %c, %lu, %lu\n",
+		(int) ppid, (unsigned long) data.proc_state.flags,
 		data.proc_state.cmd, data.proc_state.state,
-		data.proc_state.uid, data.proc_state.gid);
+		(unsigned long) data.proc_state.uid,
+		(unsigned long) data.proc_state.gid);
 
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_uid (&data.proc_uid, ppid);
 
-	printf ("Proc_Uid     PPID %5u (0x%08lx): "
-		"%d %d %d %d %d %d %d %d %d %d %d %d\n", ppid,
+	printf ("Proc_Uid     PPID %5d (0x%08lx): "
+		"%d %d %d %d %d %d %d %d %d %d %d %d\n", (int) ppid,
 		(unsigned long) data.proc_uid.flags,
 		data.proc_uid.uid, data.proc_uid.euid,
 		data.proc_uid.gid, data.proc_uid.egid,
@@ -351,8 +338,8 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_mem (&data.proc_mem, ppid);
 
-	printf ("Proc_Mem     PPID %5u (0x%08lx): "
-		"%lu %lu %lu %lu %lu %lu\n", ppid,
+	printf ("Proc_Mem     PPID %5d (0x%08lx): "
+		"%lu %lu %lu %lu %lu %lu\n", (int) ppid,
 		(unsigned long) data.proc_mem.flags,
 		(unsigned long) data.proc_mem.size,
 		(unsigned long) data.proc_mem.vsize,
@@ -364,8 +351,8 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_segment (&data.proc_segment, ppid);
 
-	printf ("Proc_Segment PPID %5u (0x%08lx): "
-		"%lu %lu %lu %lu %lu %lu %lu %lu\n", ppid,
+	printf ("Proc_Segment PPID %5d (0x%08lx): "
+		"%lu %lu %lu %lu %lu %lu %lu %lu\n", (int) ppid,
 		(unsigned long) data.proc_segment.flags,
 		(unsigned long) data.proc_segment.text_rss,
 		(unsigned long) data.proc_segment.shlib_rss,
@@ -379,8 +366,8 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_time (&data.proc_time, ppid);
 
-	printf ("Proc_Time    PPID %5u (0x%08lx): "
-		"%lu %lu %lu %lu %lu %lu %lu %lu %lu\n", ppid,
+	printf ("Proc_Time    PPID %5d (0x%08lx): "
+		"%lu %lu %lu %lu %lu %lu %lu %lu %lu\n", (int) ppid,
 		(unsigned long) data.proc_time.flags,
 		(unsigned long) data.proc_time.start_time,
 		(unsigned long) data.proc_time.rtime,
@@ -395,8 +382,8 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_signal (&data.proc_signal, ppid);
 
-	printf ("Proc_Signal  PPID %5u (0x%08lx): %lu %lu %lu %lu\n", ppid,
-		(unsigned long) data.proc_signal.flags,
+	printf ("Proc_Signal  PPID %5d (0x%08lx): %lu %lu %lu %lu\n",
+		(int) ppid, (unsigned long) data.proc_signal.flags,
 		(unsigned long) data.proc_signal.signal,
 		(unsigned long) data.proc_signal.blocked,
 		(unsigned long) data.proc_signal.sigignore,
@@ -405,8 +392,8 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_kernel (&data.proc_kernel, ppid);
 
-	printf ("Proc_Kernel  PPID %5u (0x%08lx): "
-		"%lu %lu %lu %lu %lu %lu %lu %lu (%s)\n", ppid,
+	printf ("Proc_Kernel  PPID %5d (0x%08lx): "
+		"%lu %lu %lu %lu %lu %lu %lu %lu (%s)\n", (int) ppid,
 		(unsigned long) data.proc_kernel.flags,
 		(unsigned long) data.proc_kernel.k_flags,
 		(unsigned long) data.proc_kernel.min_flt,
@@ -423,15 +410,16 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_state (&data.proc_state, 1);
 
-	printf ("Proc_State   INIT %5u (0x%08lx): '%s', %c, %u, %u\n", 1,
+	printf ("Proc_State   INIT %5d (0x%08lx): '%s', %c, %lu, %lu\n", 1,
 		(unsigned long) data.proc_state.flags,
 		data.proc_state.cmd, data.proc_state.state,
-		data.proc_state.uid, data.proc_state.gid);
+		(unsigned long) data.proc_state.uid,
+		(unsigned long) data.proc_state.gid);
 
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_uid (&data.proc_uid, 1);
 
-	printf ("Proc_Uid     INIT %5u (0x%08lx): "
+	printf ("Proc_Uid     INIT %5d (0x%08lx): "
 		"%d %d %d %d %d %d %d %d %d %d %d %d\n", 1,
 		(unsigned long) data.proc_uid.flags,
 		data.proc_uid.uid, data.proc_uid.euid,
@@ -444,7 +432,7 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_mem (&data.proc_mem, 1);
 
-	printf ("Proc_Mem     INIT %5u (0x%08lx): "
+	printf ("Proc_Mem     INIT %5d (0x%08lx): "
 		"%lu %lu %lu %lu %lu %lu\n", 1,
 		(unsigned long) data.proc_mem.flags,
 		(unsigned long) data.proc_mem.size,
@@ -457,7 +445,7 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_segment (&data.proc_segment, 1);
 
-	printf ("Proc_Segment INIT %5u (0x%08lx): "
+	printf ("Proc_Segment INIT %5d (0x%08lx): "
 		"%lu %lu %lu %lu %lu %lu %lu %lu\n", 1,
 		(unsigned long) data.proc_segment.flags,
 		(unsigned long) data.proc_segment.text_rss,
@@ -472,7 +460,7 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_time (&data.proc_time, 1);
 
-	printf ("Proc_Time    INIT %5u (0x%08lx): "
+	printf ("Proc_Time    INIT %5d (0x%08lx): "
 		"%lu %lu %lu %lu %lu %lu %lu %lu %lu\n", 1,
 		(unsigned long) data.proc_time.flags,
 		(unsigned long) data.proc_time.start_time,
@@ -488,7 +476,7 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_signal (&data.proc_signal, 1);
 
-	printf ("Proc_Signal  INIT %5u (0x%08lx): "
+	printf ("Proc_Signal  INIT %5d (0x%08lx): "
 		"%lu %lu %lu %lu\n", 1,
 		(unsigned long) data.proc_signal.flags,
 		(unsigned long) data.proc_signal.signal,
@@ -499,7 +487,7 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_kernel (&data.proc_kernel, 1);
 
-	printf ("Proc_Kernel  INIT %5u (0x%08lx): "
+	printf ("Proc_Kernel  INIT %5d (0x%08lx): "
 		"%lu %lu %lu %lu %lu %lu %lu %lu (%s)\n", 1,
 		(unsigned long) data.proc_kernel.flags,
 		(unsigned long) data.proc_kernel.k_flags,
