@@ -1,4 +1,4 @@
-/* $Id: mem.c,v 1.5 1998/08/08 20:04:00 martin Exp $ */
+/* $Id: mem.c,v 1.6 1998/08/24 19:55:24 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -53,8 +53,8 @@ static struct nlist nlst [] = {
 };
 
 /* MIB array for sysctl */
-static const int mib_length=2;
-static const int mib [] = { CTL_VM, VM_METER };
+static int mib_length=2;
+static int mib [] = { CTL_VM, VM_METER };
 
 /* Init function. */
 
@@ -89,7 +89,7 @@ glibtop_get_mem_p (glibtop *server, glibtop_mem *buf)
 	struct vmmeter vmm;
 	int bufspace;
 
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_MEM, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_MEM), 0);
 	
 	memset (buf, 0, sizeof (glibtop_mem));
 
