@@ -1,4 +1,4 @@
-/* $Id: msg_limits.c,v 1.4 1998/08/08 20:04:01 martin Exp $ */
+/* $Id: msg_limits.c,v 1.5 1998/08/24 19:55:25 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -68,7 +68,7 @@ glibtop_init_msg_limits_p (glibtop *server)
 void
 glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 {
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_MSG_LIMITS, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
 	
 	memset (buf, 0, sizeof (glibtop_msg_limits));
 
