@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.7 1998/08/14 16:41:56 martin Exp $ */
+/* $Id: proclist.c,v 1.8 1998/08/24 19:55:27 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -65,7 +65,7 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 	int count;
 	int i;
 
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROCLIST, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROCLIST), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proclist));
 
