@@ -1,4 +1,4 @@
-/* $Id: procmem.c,v 1.8 1998/08/12 23:05:35 martin Exp $ */
+/* $Id: procmem.c,v 1.9 1998/08/24 19:55:29 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -97,6 +97,10 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 	struct inode inode;
 	int count;
 
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_MEM), 0);
+	
+	memset (buf, 0, sizeof (glibtop_proc_mem));
+
 	glibtop_suid_enter (server);
 
 	/* Get the process data */
