@@ -1,4 +1,4 @@
-/* $Id: procsignal.c,v 1.5 1998/08/10 08:09:34 martin Exp $ */
+/* $Id: procsignal.c,v 1.6 1998/08/24 19:55:31 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -47,7 +47,7 @@ glibtop_get_proc_signal_p (glibtop *server,
 	struct kinfo_proc *pinfo;
 	int count = 0;
 
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_SIGNAL, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_SIGNAL), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_signal));
 
