@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.4 1998/08/08 20:04:06 martin Exp $ */
+/* $Id: swap.c,v 1.5 1998/08/24 19:55:37 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -88,7 +88,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
         static int swappgsin = -1;
 	static int swappgsout = -1;
 
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_SWAP, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_SWAP), 0);
 	
 	memset (buf, 0, sizeof (glibtop_swap));
 
