@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.3 1998/08/08 20:04:07 martin Exp $ */
+/* $Id: uptime.c,v 1.4 1998/08/24 19:55:38 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -49,7 +49,7 @@ glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
 {
 	glibtop_cpu cpu;
 
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_UPTIME, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_UPTIME), 0);
 	
 	memset (buf, 0, sizeof (glibtop_uptime));
 
