@@ -19,9 +19,19 @@
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-#include <config.h>
+#include <glibtop.h>
 #include <glibtop/cpu.h>
 
+static const unsigned long _glibtop_sysdeps_cpu = 0;
+
+/* Init function. */
+
+void
+glibtop_init_cpu_s (glibtop *server)
+{
+	server->sysdeps.cpu = _glibtop_sysdeps_cpu;
+}
+
 /* Provides information about cpu usage. */
 
 void
