@@ -19,9 +19,19 @@
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-#include <config.h>
+#include <glibtop.h>
 #include <glibtop/mem.h>
 
+static const unsigned long _glibtop_sysdeps_mem = 0;
+
+/* Init function. */
+
+void
+glibtop_init_mem_s (glibtop *server)
+{
+	server->sysdeps.mem = _glibtop_sysdeps_mem;
+}
+
 /* Provides information about memory usage. */
 
 void
