@@ -19,11 +19,21 @@
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-#include <config.h>
+#include <glibtop.h>
 #include <glibtop/proclist.h>
 
 #define GLIBTOP_PROCLIST_FLAGS	3
 
+static const unsigned long _glibtop_sysdeps_proclist = 0;
+
+/* Init function. */
+
+void
+glibtop_init_proclist_s (glibtop *server)
+{
+	server->sysdeps.proclist = _glibtop_sysdeps_proclist;
+}
+
 /* Fetch list of currently running processes.
  *
  * IMPORTANT NOTE:
@@ -32,7 +42,8 @@
  *   each buf->size big. The total size is stored in buf->total. */
 
 unsigned *
-glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf)
+glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
+			int64_t which, int64_t arg)
 {
 	memset (buf, 0, sizeof (glibtop_proclist));
 	return NULL;
