@@ -22,6 +22,8 @@
 #include <glibtop.h>
 #include <glibtop/loadavg.h>
 
+#include <glibtop_suid.h>
+
 static const unsigned long _glibtop_sysdeps_loadavg =
 (1 << GLIBTOP_LOADAVG_LOADAVG);
 
@@ -33,7 +35,7 @@ glibtop_get_loadavg_p (glibtop *server, glibtop_loadavg *buf)
 	load_avg avenrun [3];
 	int i;
 
-	glibtop_init_p (&server, 0, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_LOADAVG), 0);
 
 	memset (buf, 0, sizeof (glibtop_loadavg));
 
