@@ -22,6 +22,8 @@
 #include <glibtop.h>
 #include <glibtop/msg_limits.h>
 
+#include <glibtop_suid.h>
+
 /* #define KERNEL to get declaration of `struct msginfo'. */
 
 #define KERNEL
@@ -41,7 +43,7 @@ glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 {
 	struct msginfo	msginfo;
   
-	glibtop_init_p (&server, 0, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
 
 	memset (buf, 0, sizeof (glibtop_msg_limits));
   
