@@ -23,6 +23,8 @@
 #include <glibtop/xmalloc.h>
 #include <glibtop/proclist.h>
 
+#include <glibtop_suid.h>
+
 static const unsigned long _glibtop_sysdeps_proclist =
 (1 << GLIBTOP_PROCLIST_TOTAL) + (1 << GLIBTOP_PROCLIST_NUMBER) +
 (1 << GLIBTOP_PROCLIST_SIZE);
@@ -35,14 +37,15 @@ static const unsigned long _glibtop_sysdeps_proclist =
  *   each buf->size big. The total size is stored in buf->total. */
 
 unsigned *
-glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf)
+glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
+			int64_t which, int64_t arg)
 {
 	register struct proc *pp;
 	register int i, nproc = 0;
 	unsigned *proc_list = NULL;
 	size_t proc_size;
 
-	glibtop_init_p (&server, 0, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROCLIST), 0);
 
 	memset (buf, 0, sizeof (glibtop_proclist));
 
