@@ -22,8 +22,11 @@
 #include <glibtop.h>
 #include <glibtop/procsegment.h>
 
+#include <glibtop_suid.h>
+
 static const unsigned long _glibtop_sysdeps_proc_segment =
-(1 << GLIBTOP_PROC_SEGMENT_TRS) + (1 << GLIBTOP_PROC_SEGMENT_DRS);
+(1 << GLIBTOP_PROC_SEGMENT_TEXT_RSS) +
+(1 << GLIBTOP_PROC_SEGMENT_DATA_RSS);
 
 /* Provides detailed information about a process. */
 
@@ -33,7 +36,7 @@ glibtop_get_proc_segment_p (glibtop *server, glibtop_proc_segment *buf,
 {
 	struct proc *pp;
 
-	glibtop_init_p (&server, 0, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_SEGMENT), 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_segment));
 
@@ -49,8 +52,8 @@ glibtop_get_proc_segment_p (glibtop *server, glibtop_proc_segment *buf,
 
 	/* Fill in data fields. */
 
-	buf->trs = pp->p_tsize;
-	buf->drs = pp->p_dsize;
+	buf->text_rss = pp->p_tsize;
+	buf->data_rss = pp->p_dsize;
 
 	buf->flags = _glibtop_sysdeps_proc_segment;
 }
