@@ -22,6 +22,8 @@
 #include <glibtop.h>
 #include <glibtop/procuid.h>
 
+#include <glibtop_suid.h>
+
 static const unsigned long _glibtop_sysdeps_proc_uid =
 (1 << GLIBTOP_PROC_UID_UID) + (1 << GLIBTOP_PROC_UID_EUID) +
 (1 << GLIBTOP_PROC_UID_EGID) + (1 << GLIBTOP_PROC_UID_PID) +
@@ -37,7 +39,7 @@ glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf,
 {
 	struct proc *pp;
 
-	glibtop_init_p (&server, 0, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_UID), 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_uid));
 
