@@ -22,12 +22,14 @@
 #include <glibtop.h>
 #include <glibtop/swap.h>
 
+#include <glibtop_suid.h>
+
 /* Provides information about swap usage. */
 
 void
 glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 {
-	glibtop_init_p (&server, 0, 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_SWAP), 0);
 
 	memset (buf, 0, sizeof (glibtop_swap));
 }
